@@ -31,12 +31,14 @@ class SharePointAPI:
         sharepoint_url = credentials['sharepoint_url']
         proxies = credentials['proxies']
 
+        sharepoint_api = object.__new__(SharePointAPI)
+        sharepoint_api.__init__(username, password, sharepoint_url, proxies)
 
-        return cls(username, password, sharepoint_url, proxies)
+        return sharepoint_api
 
     def __init__(self, username: str, password: str, sharepoint_url: str, proxies: dict):
         '''
-        
+
         '''
 
         self.username = username
@@ -59,10 +61,8 @@ class SharePointAPI:
         if merge:
             headers['X-HTTP-Method'] = 'MERGE'
 
-
-
         r = requests.post(url,
-                         auth=HttpNtlmAuth(self.username, self.password), headers=headers, json=post_data, proxies=self.proxies)
+                          auth=HttpNtlmAuth(self.username, self.password), headers=headers, json=post_data, proxies=self.proxies)
 
         if r.status_code == 400:
             print('Failed to connect: ', r.status_code)
@@ -100,11 +100,10 @@ class SharePointAPI:
         if post_data:
             headers['Content-Length'] = str(len(f'{post_data}'))
             r = requests.post(url,
-                         auth=HttpNtlmAuth(self.username, self.password), data=post_data, headers=headers, proxies=self.proxies)
+                              auth=HttpNtlmAuth(self.username, self.password), data=post_data, headers=headers, proxies=self.proxies)
         else:
             r = requests.post(url,
-                         auth=HttpNtlmAuth(self.username, self.password), headers=headers, proxies=self.proxies)
-
+                              auth=HttpNtlmAuth(self.username, self.password), headers=headers, proxies=self.proxies)
 
         if r.status_code == 404:
             print('Failed to connect: ', r.status_code)
@@ -143,7 +142,6 @@ class SharePointAPI:
         r = requests.get(url,
                          auth=HttpNtlmAuth(self.username, self.password), headers=headers, proxies=self.proxies)
 
-
         if r.status_code == 404:
             print('Failed to process request with status code ', r.status_code)
             print(r.json()['error']['message']['value'])
@@ -167,7 +165,8 @@ class SharePointAPI:
         '''
             Returns a list of users from a given sharepoint_site
         '''
-        r = self._api_get_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/siteusers')
+        r = self._api_get_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/siteusers')
 
         users = []
 
@@ -182,7 +181,8 @@ class SharePointAPI:
         '''
         if user_id is None:
             return SharePointUser()
-        r = self._api_get_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/siteusers?$filter=( Id eq {user_id} )')
+        r = self._api_get_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/siteusers?$filter=( Id eq {user_id} )')
 
         user_settings = r.json()["d"]["results"][0]
         return SharePointUser(user_settings)
@@ -193,15 +193,16 @@ class SharePointAPI:
         '''
             Returns a list of lists from a given sharepoint_site
         '''
-        r = self._api_get_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists')
+        r = self._api_get_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists')
 
         _lists = []
         for list_props in r.json()["d"]["results"]:
-                _lists.append(SharePointList(sharepoint_site, list_props))
+            _lists.append(SharePointList(sharepoint_site, list_props))
 
         return SharePointLists(_lists)
 
-    def get_list(self, sharepoint_site, sp_list, filters=None, top=1000, view_path=None, SPListType: SharePointList=SharePointList) -> SharePointList:
+    def get_list(self, sharepoint_site, sp_list, filters=None, top=1000, view_path=None, SPListType: SharePointList = SharePointList) -> SharePointList:
         '''
             Returns a list from a given sharepoint_site using its guid
 
@@ -214,43 +215,47 @@ class SharePointAPI:
         # Uses either guid or SharePointList
         if isinstance(sp_list, SharePointList):
             guid = sp_list.guid
-            r = self._api_get_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')')
+            r = self._api_get_call(
+                f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')')
             sp_list = SPListType(sharepoint_site, r.json()["d"])
 
         elif isinstance(sp_list, str):
             guid = sp_list
-            r = self._api_get_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')')
+            r = self._api_get_call(
+                f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')')
             sp_list = SPListType(sharepoint_site, r.json()["d"])
         else:
             sys.exit(1)
 
         arguments = []
-        
+
         if filters is not None:
             if not isinstance(filters, list):
                 filter_string = self.py2sp_conditional(filters)
                 # print(filters)
                 # raise('invalid search filters')
             else:
-            
+
                 filter_string = self.py2sp_conditional(' and '.join(filters))
             arguments.append(f'$filter={filter_string}')
-            
+
         if view_path is not None:
             # Shows top x items
             arguments.append(f'$ViewPath={view_path}')
-        
+
         if top is not None:
             # Shows top x items
             arguments.append(f'$top={top}')
 
-        r = self._api_get_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items?{"&".join(arguments)}')
+        r = self._api_get_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items?{"&".join(arguments)}')
 
-        items = [SPListType.SPItem(self, sharepoint_site, guid, item_settings) for item_settings in r.json()["d"]["results"]]
+        items = [SPListType.SPItem(self, sharepoint_site, guid, item_settings)
+                 for item_settings in r.json()["d"]["results"]]
         sp_list.append_items(items)
         return sp_list
 
-    def get_list_by_name(self, sharepoint_site, sp_list_name: str, filters=None, top=1000, view_path=None, SPListType: SharePointList=SharePointList) -> SharePointList:
+    def get_list_by_name(self, sharepoint_site, sp_list_name: str, filters=None, top=1000, view_path=None, SPListType: SharePointList = SharePointList) -> SharePointList:
         '''
             Returns a list from a given sharepoint_site filtering by list name
 
@@ -267,10 +272,11 @@ class SharePointAPI:
         if sp_list_name in sp_lists.all_list_titles:
             return self.get_list(sharepoint_site, sp_lists.get_list(sp_list_name), filters, top, view_path, SPListType=SPListType)
         else:
-            print(f"List '{sp_list_name}' does not exist in sharepoint_site {sharepoint_site}'")
+            print(
+                f"List '{sp_list_name}' does not exist in sharepoint_site {sharepoint_site}'")
             sys.exit(1)
 
-    def get_list_from_json(self, file_name, SPListType: SharePointList=SharePointList) -> SharePointList:
+    def get_list_from_json(self, file_name, SPListType: SharePointList = SharePointList) -> SharePointList:
         '''
             Returns a list from a sharepoint_site based on a json file.
 
@@ -288,7 +294,8 @@ class SharePointAPI:
             for case in data_dict['cases']:
                 settings = case["settings"]
                 versions = None if "versions" not in case else case["versions"]
-                cases.append(SPListType.SPItem(self, sharepoint_site, guid, settings, versions))
+                cases.append(SPListType.SPItem(
+                    self, sharepoint_site, guid, settings, versions))
 
             return SPListType(sharepoint_site, data_dict['Settings'], cases)
         except FileNotFoundError as err:
@@ -312,7 +319,8 @@ class SharePointAPI:
         else:
             sys.exit(1)
 
-        r = self._api_get_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item_id})')
+        r = self._api_get_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item_id})')
 
         settings = r.json()["d"]
         return SharePointListItem(self, sharepoint_site, guid, settings)
@@ -323,15 +331,19 @@ class SharePointAPI:
             guid = sp_list.guid
         elif isinstance(sp_list, str):
             guid = sp_list
-            r = self._api_get_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')')
-            sp_list = SharePointList(sharepoint_site, r.json()["d"]["results"][0])
+            r = self._api_get_call(
+                f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')')
+            sp_list = SharePointList(
+                sharepoint_site, r.json()["d"]["results"][0])
 
+        r = self._api_post_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
 
-        r = self._api_post_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
+        form_digest_value = r.json(
+        )["d"]["GetContextWebInformation"]["FormDigestValue"]
 
-        form_digest_value = r.json()["d"]["GetContextWebInformation"]["FormDigestValue"]
-
-        r = self._api_post_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items', data, form_digest_value)
+        r = self._api_post_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items', data, form_digest_value)
 
         settings = r.json()["d"]
         return SharePointListItem(self, sharepoint_site, guid, settings)
@@ -349,17 +361,22 @@ class SharePointAPI:
             guid = sp_list.guid
         elif isinstance(sp_list, str):
             guid = sp_list
-            r = self._api_get_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')')
-            sp_list = SharePointList(sharepoint_site, r.json()["d"]["results"][0])
+            r = self._api_get_call(
+                f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')')
+            sp_list = SharePointList(
+                sharepoint_site, r.json()["d"]["results"][0])
         else:
-            raise TypeError('Only "SharePointList" and "str" types are allowed')
+            raise TypeError(
+                'Only "SharePointList" and "str" types are allowed')
 
+        r = self._api_post_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
 
-        r = self._api_post_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
+        form_digest_value = r.json(
+        )["d"]["GetContextWebInformation"]["FormDigestValue"]
 
-        form_digest_value = r.json()["d"]["GetContextWebInformation"]["FormDigestValue"]
-
-        r = self._api_post_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item_id})', data, form_digest_value, merge=True)
+        r = self._api_post_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item_id})', data, form_digest_value, merge=True)
 
     def attach_file(self, sharepoint_site, sp_list, item, file_name, file_content) -> dict:
         # Uses either guid or SharePointList
@@ -368,12 +385,16 @@ class SharePointAPI:
         elif isinstance(sp_list, str):
             guid = sp_list
         else:
-            raise TypeError('Only "SharePointList" and "str" types are allowed')
+            raise TypeError(
+                'Only "SharePointList" and "str" types are allowed')
 
-        r = self._api_post_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
-        form_digest_value = r.json()["d"]["GetContextWebInformation"]["FormDigestValue"]
+        r = self._api_post_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
+        form_digest_value = r.json(
+        )["d"]["GetContextWebInformation"]["FormDigestValue"]
 
-        r = self._api_attachment_call(f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item.Id})/AttachmentFiles/ add(FileName='{file_name}')", file_content, form_digest_value)
+        r = self._api_attachment_call(
+            f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item.Id})/AttachmentFiles/ add(FileName='{file_name}')", file_content, form_digest_value)
 
         return r.json()
 
@@ -390,7 +411,8 @@ class SharePointAPI:
         else:
             sys.exit(1)
 
-        r = self._api_get_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item_id})/Versions')
+        r = self._api_get_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item_id})/Versions')
 
         versions = r.json()["d"]['results']
         return versions
@@ -431,7 +453,7 @@ class SharePointAPI:
             top: Maximum items to query from the list
         '''
         return self.get_list_by_name(sharepoint_site, sp_list_name, filters, top, view_path, SPListType=CasesList)
-    
+
     def get_case(self, sharepoint_site, sp_list, item_id) -> SharePointListItem:
         '''
             Returns a list of users from a given sharepoint_site
@@ -445,7 +467,8 @@ class SharePointAPI:
         else:
             sys.exit(1)
 
-        r = self._api_get_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item_id})')
+        r = self._api_get_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/Lists(guid\'{guid}\')/items({item_id})')
 
         settings = r.json()["d"]
         return SharepointSiteCase(self, sharepoint_site, guid, settings)
@@ -497,7 +520,8 @@ class SharePointAPI:
         if in_doc_lib:
             folder = os.path.join("DocumentLibrary", folder)
 
-        r = self._api_get_call(f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/GetFolderByServerRelativeUrl('/cases/{sharepoint_site}/{folder}')/ListItemAllFields")
+        r = self._api_get_call(
+            f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/GetFolderByServerRelativeUrl('/cases/{sharepoint_site}/{folder}')/ListItemAllFields")
 
         return False if ("ListItemAllFields" in r.json()["d"] and r.json()["d"]["ListItemAllFields"] is None) else True
 
@@ -509,15 +533,17 @@ class SharePointAPI:
         if in_doc_lib:
             folder = os.path.join("DocumentLibrary", folder)
 
-        r = self._api_post_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
-        form_digest_value = r.json()["d"]["GetContextWebInformation"]["FormDigestValue"]
+        r = self._api_post_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
+        form_digest_value = r.json(
+        )["d"]["GetContextWebInformation"]["FormDigestValue"]
 
         r = self._api_post_call(f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/web/folders",
-                form_digest_value=form_digest_value,
-                post_data={
-                    "ServerRelativeUrl": f'/cases/{sharepoint_site}/{folder}/{new_folder}',
-                }
-            )
+                                form_digest_value=form_digest_value,
+                                post_data={
+                                    "ServerRelativeUrl": f'/cases/{sharepoint_site}/{folder}/{new_folder}',
+                                }
+                                )
 
         return r.status_code
 
@@ -529,7 +555,8 @@ class SharePointAPI:
         if in_doc_lib:
             folder = os.path.join("DocumentLibrary", folder)
 
-        r = self._api_get_call(f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/GetFolderByServerRelativeUrl('/cases/{sharepoint_site}/{folder}')/Files")
+        r = self._api_get_call(
+            f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/GetFolderByServerRelativeUrl('/cases/{sharepoint_site}/{folder}')/Files")
 
         return r.json()["d"]["results"]
 
@@ -541,10 +568,10 @@ class SharePointAPI:
         if in_doc_lib:
             folder = os.path.join("DocumentLibrary", folder)
 
-        r = self._api_get_call(f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/GetFolderByServerRelativeUrl('/cases/{sharepoint_site}/{folder}')/Files('{file}')/$value")
+        r = self._api_get_call(
+            f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/GetFolderByServerRelativeUrl('/cases/{sharepoint_site}/{folder}')/Files('{file}')/$value")
         return r._content
 
-
     def download_file(self, sharepoint_site, folder, file, out_file=None, in_doc_lib=True):
         '''
             Downloads and saves a file from a folder in a given sharepoint_site
@@ -556,7 +583,8 @@ class SharePointAPI:
         if not out_file:
             out_file = file
 
-        file_content = self.get_file_content(sharepoint_site, folder, file, in_doc_lib)
+        file_content = self.get_file_content(
+            sharepoint_site, folder, file, in_doc_lib)
 
         with open(out_file, 'wb') as f:
             f.write(file_content)
@@ -569,8 +597,10 @@ class SharePointAPI:
         if in_doc_lib:
             folder = os.path.join("DocumentLibrary", folder)
 
-        r = self._api_post_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
-        form_digest_value = r.json()["d"]["GetContextWebInformation"]["FormDigestValue"]
+        r = self._api_post_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
+        form_digest_value = r.json(
+        )["d"]["GetContextWebInformation"]["FormDigestValue"]
 
         r = self._api_attachment_call(
             f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/GetFolderByServerRelativeUrl('/cases/{sharepoint_site}/{folder}')/Files/add(url='{file}',overwrite={str(overwrite).lower()})",
@@ -601,8 +631,10 @@ class SharePointAPI:
         if in_doc_lib:
             folder = os.path.join("DocumentLibrary", folder)
 
-        r = self._api_post_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
-        form_digest_value = r.json()["d"]["GetContextWebInformation"]["FormDigestValue"]
+        r = self._api_post_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
+        form_digest_value = r.json(
+        )["d"]["GetContextWebInformation"]["FormDigestValue"]
 
         r = self._api_attachment_call(
             url=f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/GetFolderByServerRelativeUrl('/cases/{sharepoint_site}/{folder}')/Files('{file}')",
@@ -624,16 +656,18 @@ class SharePointAPI:
         if not out_folder:
             out_folder = folder
 
-        r = self._api_post_call(f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
-        form_digest_value = r.json()["d"]["GetContextWebInformation"]["FormDigestValue"]
+        r = self._api_post_call(
+            f'{self.sharepoint_url}/cases/{sharepoint_site}/_api/contextinfo', {})
+        form_digest_value = r.json(
+        )["d"]["GetContextWebInformation"]["FormDigestValue"]
 
         in_path = f"/cases/{sharepoint_site}/{folder}"
         out_path = f"/cases/{sharepoint_site}/{out_folder}/{out_file}"
 
         r = self._api_attachment_call(
             f"{self.sharepoint_url}/cases/{sharepoint_site}/_api/Web/GetFolderByServerRelativeUrl('{in_path}')/Files('{file}')/copyto(strnewurl='{out_path}',boverwrite={str(overwrite).lower()})",
-             None,
-             form_digest_value)
+            None,
+            form_digest_value)
 
     # STATIC METHODS
 
